Description
Convenience functions that simply tasks by allowing them to be executed from the R console such as opening the OMOP Concept page.
Add the following code to your website.
REMOVE THIS Copy to clipboard
For more information on customizing the embed code, read Embedding Snippets.