A Label is in the format of "concept_id concept_name". It is less comprehensive than a merged strip using the merge_concepts function, but more human readable when interfacing with others.
1 |
unite
reexports,mutate_all,vars
Other concept format functions:
filter_at_all_strip(),
filter_at_any_strip(),
filter_strip(),
get_strip(),
label_to_strip(),
merge_strip(),
unbox_label(),
unbox_strip(),
unmerge_label(),
unmerge_strip()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.